# rdopkg

`rdopkg` is RDO packaging tool. It provides automation for modifying,
building and submitting (not only) [RDO](https://openstack.redhat.com) RPM
packages.

All information is provided in rdopkg manual, you can read its [nice
source](doc/rdopkg.1.txt) or render it to HTML/man pages with asciidoc:

    make doc

It's planned to render the manual on RDO site as well.
